clear mata
capture clear matrix
clear 
set memory 600m
set matsize 5000
set maxvar 32767
set more off

cd ""

********************
***1991-1995 PETS***
********************

insheet using "PETSUganda199195RAW.csv"

	keep scode district year students teachers qualteach teachsal_gvt teachsal_pta pta_fees tuitioncollected tuitionretained
	
	rename students totenroll
	rename teachers nbteach
	rename qualteach nbqualteach
	rename pta_fees ptafees
	
	g teachsalglob=(teachsal_gvt+teachsal_pta)
	rename teachsal_gvt teachsal
	g totenroll_nbteach=totenroll/nbteach
	g totenroll_nbqualteach=totenroll/nbqualteach
		
	replace year = 1991 if year==91
	replace year = 1992 if year==92
	replace year = 1993 if year==93
	replace year = 1994 if year==94
	replace year = 1995 if year==95
	
	sort scode year
	
	tempfile pets199195
	save "`pets199195'"
	
***************************
***Consumption 1991-2001***
***************************	
	
use "JPubE\Data19952002_sample388_consumption.dta"
	
	rename code scode
	keep scode year consumption
	drop if year==2002
	
	merge m:m scode year using "`pets199195'"
	drop _merge 
	rename consumption consump

	tempfile nonpets
	save "`nonpets'"

*******************************
***Capture for 1991 and 1995***
*******************************

use "JEEA\Data1991_sample250_extended.dta", clear
	
	keep scode capture
	g year=1991
	rename capture capture1991
	
	merge 1:m scode year using "`nonpets'"
	drop _merge
	
	save "`nonpets'", replace

use "JEEA\Data1995_sample250_extended.dta", clear
	
	keep scode capture
	g year=1995
	rename capture capture1995
	merge 1:m scode year using "`nonpets'"
	drop _merge

	g capture =.
	replace capture = capture1991 if year==1991
	replace capture = capture1995 if year==1995
	drop capture1991 capture1995
	save "`nonpets'", replace

***********************
***P3 data from EMIS***
***********************

use "JPubE\EMIS_p3students.dta", clear
	
	collapse p3students, by(scode year)
	merge m:m scode year using "`nonpets'"
	drop _merge
	rename p3students enrollg3
	
	save "`nonpets'", replace


*************************
***Enrollment from PLE***
*************************

use "JPubE\testscore1991.dta", clear
	
	g test=english+science+sst+mathematics
	collapse (count) test, by(wbcode)
	rename (test wbcode) (enrollg7 scode)
	g year=1991
	
	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace

foreach x in 1995 1997 2001{
use "JPubE\testscore`x'.dta", clear
	
	g test=englishgrade+sciencegrade+sstgrade+mathgrade
	collapse (count) test, by(wbcode)
	rename (test wbcode) (enrollg7 scode)
	g year=`x'
	
	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace
	}

******************************
***Avg test scores from PLE***
******************************

use "JPubE\testscore1991.dta", clear
	g test=english+science+sst+mathematics
	collapse (mean) test, by(wbcode)
	rename (test wbcode) (ple scode)
	g year=1991

	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace

foreach x in 1995 1997 2001{
use "JPubE\testscore`x'.dta", clear
	g test=englishgrade+sciencegrade+sstgrade+mathgrade
	collapse (mean) test, by(wbcode)
	rename (test wbcode) (ple scode)
	g year=`x'

	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace
	}

****************************************
***Avg test scores from PLE by gender***
****************************************

foreach x in 1995 2001{
use "JPubE\testscore`x'.dta", clear
	g testf=englishgrade+sciencegrade+sstgrade+mathgrade
	collapse (mean) testf if gender==0, by(wbcode)
	rename (testf wbcode) (plef scode)
	g year=`x'
	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace
	}

foreach x in 1995 2001{
use "JPubE\testscore`x'.dta", clear
	g testm=englishgrade+sciencegrade+sstgrade+mathgrade
	collapse (mean) testm if gender==1, by(wbcode)
	rename (testm wbcode) (plem scode)
	g year=`x'
	merge 1:m scode year using "`nonpets'"
	drop _merge
	save "`nonpets'", replace
	}

********************
***2002 PETS data***
********************

use "JEEA\PETS2002UGA.dta", clear

	g scode = q1scode
	
	rename q24teac nbteach
	rename q25qual nbqualteach
	
	g panel_sample=0
	replace panel_sample=1 if scode>0 & scode<=250

	count
	count if panel_sample==1

	foreach x of varlist q89*{
	ta `x', missing
	}
	
	g check_non2001=.
	
	egen jan01_count=anycount(q89ajan*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88ajan!=. & jan01_count>0)
	
	egen feb01_count=anycount(q89bfeb*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88bfeb!=. & feb01_count>0)
	
	egen mar01_count=anycount(q89cmar*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88cmar!=. & mar01_count>0)
	
	egen apr01_count=anycount(q89dapr*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88dapr!=. & apr01_count>0)
	
	egen may01_count=anycount(q89emay*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88emay!=. & may01_count>0)
	
	egen jun01_count=anycount(q89fjun*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88fjun!=. & jun01_count>0)
	
	egen jul01_count=anycount(q89gjul*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88gjul!=. & jul01_count>0)
	
	egen aug01_count=anycount(q89haug*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88haug!=. & aug01_count>0)
	
	egen sep01_count=anycount(q89isep*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88isep!=. & sep01_count>0)
	
	egen oct01_count=anycount(q89joct*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88joct!=. & oct01_count>0)
	
	egen nov01_count=anycount(q89knov*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88knov!=. & nov01_count>0)
		
	egen dec01_count=anycount(q89ldec*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88ldec!=. & dec01_count>0)
	
	egen jan02_count=anycount(q89mjan*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88mjan!=. & jan02_count>0)
	
	egen feb02_count=anycount(q89nfeb*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88nfeb!=. & feb02_count>0)
	
	egen mar02_count=anycount(q89omar*), value(102, 202, 302, 402, 502, 602, 900, 1000, 1007, 1020, 1100, 1120, 1200, 1220, 3012)
	replace check_non2001=1 if (q88omar!=. & mar02_count>0)
	replace check_non2001=0 if check_non2001==.
	
	count if (q88ajan!=. & jan01_count>0) & (q88bfeb!=. & feb01_count>0) & (q88cmar!=. & mar01_count>0) & /*
	*/ (q88dapr!=. & apr01_count>0) & (q88emay!=. & may01_count>0) & (q88fjun!=. & jun01_count>0) & /*
	*/ (q88gjul!=. & jul01_count>0) & (q88haug!=. & aug01_count>0) & (q88isep!=. & sep01_count>0) & /*
	*/ (q88joct!=. & oct01_count>0) & (q88knov!=. & nov01_count>0) & (q88ldec!=. & dec01_count>0) & /*
	*/ (q88mjan!=. & jan02_count>0) & (q88nfeb!=. & feb02_count>0) &  (q88omar!=. & mar02_count>0)
	

	foreach x of varlist q89* {
	replace `x'=. if `x'==900
	replace `x'=. if `x'==1000
	replace `x'=. if `x'==1100
	replace `x'=. if `x'==1200
	replace `x'=. if `x'==102
	replace `x'=. if `x'==202
	replace `x'=. if `x'==302
	replace `x'=. if `x'==402
	replace `x'=. if `x'==1020
	replace `x'=. if `x'==1120
	replace `x'=. if `x'==1220
	replace `x'=. if `x'==502
	replace `x'=. if `x'==602
	replace `x'=. if `x'==3012
	replace `x'=. if `x'==1007
	}

	egen jan01_missing=rowtotal(q89ajanmon1 q89ajanmon2 q89ajanmon3 q89ajanmon4 q89ajanmon5 q89ajanmon6)
	egen feb01_missing=rowtotal(q89bfebmon1 q89bfebmon2 q89bfebmon3 q89bfebmon4 q89bfebmon5 q89bfebmon6)
	egen mar01_missing=rowtotal(q89cmarmon1 q89cmarmon2 q89cmarmon3 q89cmarmon4 q89cmarmon5 q89cmarmon6)	
	egen apr01_missing=rowtotal(q89daprmon1 q89daprmon2 q89daprmon3 q89daprmon4 q89daprmon5 q89daprmon6)
	egen may01_missing=rowtotal(q89emaymon1 q89emaymon2 q89emaymon3 q89emaymon4 q89emaymon5 q89emaymon6)	
	egen jun01_missing=rowtotal(q89fjunmon1 q89fjunmon2 q89fjunmon3 q89fjunmon4 q89fjunmon5 q89fjunmon6)	
	egen jul01_missing=rowtotal(q89gjulmon1 q89gjulmon2 q89gjulmon3 q89gjulmon4 q89gjulmon5 q89gjulmon6)	
	egen aug01_missing=rowtotal(q89haugmon1 q89haugmon2 q89haugmon3 q89haugmon4 q89haugmon5 q89haugmon6)	
	egen sep01_missing=rowtotal(q89isepmon1 q89isepmon2 q89isepmon3 q89isepmon4 q89isepmon5 q89isepmon6)		
	egen oct01_missing=rowtotal(q89joctmon1 q89joctmon2 q89joctmon3 q89joctmon4 q89joctmon5 q89joctmon6)		
	egen nov01_missing=rowtotal(q89knovmon1 q89knovmon2 q89knovmon3 q89knovmon4 q89knovmon5 q89knovmon6)
	egen dec01_missing=rowtotal(q89ldecmon1 q89ldecmon2 q89ldecmon3 q89ldecmon4 q89ldecmon5 q89ldecmon6)		
	egen jan02_missing=rowtotal(q89mjanmon1 q89mjanmon2 q89mjanmon3 q89mjanmon4 q89mjanmon5 q89mjanmon6)		
	egen feb02_missing=rowtotal(q89nfebmon1 q89nfebmon2 q89nfebmon3 q89nfebmon4 q89nfebmon5 q89nfebmon6)	
	egen mar02_missing=rowtotal(q89omarmon1 q89omarmon2 q89omarmon3 q89omarmon4 q89omarmon5 q89omarmon6)	

	g jan01_grant= q88ajan if jan01_missing !=0	
	g feb01_grant= q88bfeb if feb01_missing !=0
	g mar01_grant= q88cmar if mar01_missing !=0
	g apr01_grant= q88dapr if apr01_missing !=0	
	g may01_grant= q88emay if may01_missing !=0	
	g jun01_grant= q88fjun if jun01_missing !=0	
	g jul01_grant= q88gjul if jul01_missing !=0
	g aug01_grant= q88haug if aug01_missing !=0
	g sep01_grant= q88isep if sep01_missing !=0
	g oct01_grant= q88joct if oct01_missing !=0
	g nov01_grant= q88knov if nov01_missing !=0
	g dec01_grant= q88ldec if dec01_missing !=0
	g jan02_grant= q88mjan if jan02_missing !=0
	g feb02_grant= q88nfeb if feb02_missing !=0
	g mar02_grant= q88omar if mar02_missing !=0
	
	egen grantallmissing=rowmiss(jan01_grant feb01_grant mar01_grant apr01_grant may01_grant jun01_grant jul01_grant /*
	*/ aug01_grant sep01_grant oct01_grant nov01_grant/*
	*/ dec01_grant jan02_grant feb02_grant mar02_grant)	

	egen receipts_grant = rowtotal(jan01_grant feb01_grant mar01_grant apr01_grant may01_grant jun01_grant jul01_grant aug01_grant sep01_grant oct01_grant nov01_grant dec01_grant jan02_grant feb02_grant mar02_grant)
	
	g intended_grant1 = q12p13*5000 + q13p47*8100	
	g intended_grant2 = q17p13*5000 + q18p47*8100	

	g intended_grant = max(intended_grant1, intended_grant2)
	
	merge 1:1 districtn scode using "JEEA\scalefactor.dta"
	drop _merge
	ta scalefactor, m
	
	g capture = (receipts_grant / (intended_grant*scalefactor))*100
	replace capture=. if capture==0

	su capture if panel_sample==1, d
	latabstat capture  if panel_sample==1, stats(mean med SD count) f(%5.1f) columns(statistics)	

	g distance = ln(1+q29dist) 
	ta distance, missing
	
	g ht_formula = 0
	replace ht_formula = 1 if (q58p13>=4750 & q58p13<=5250) & (q58p47>=7695 & q58p47<=8505)

	g ht_timing = q63know
	replace ht_timing = 0 if q63know==2
	
	g ht_knowledge = ht_formula+ht_timing
	
	g year = 2001

	g students_2001 = max(q11stud, q16tot01)
	g totenroll_nbteach=students_2001/nbteach
	g totenroll_nbqualteach=students_2001/nbqualteach

	rename q84bsal teachsal
	rename q84dpta ptafees

	merge 1:m scode year using "`nonpets'"
	drop _merge

	replace totenroll=students_2001 if year==2001


	foreach x in 1991 1995 1997 2001{
	g consumption_`x'=consump
	replace consumption_`x' = . if year!=`x'
	bysort scode: egen consump_`x' = mean(consumption_`x')
	}

	foreach x in 1991 1995 2001{
	g cap_`x'=capture
	replace cap_`x' = . if year!=`x'
	bysort scode: egen capture_`x' = mean(cap_`x')
	}	
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g toten_`x'=totenroll
	replace toten_`x' = . if year!=`x'
	bysort scode: egen totenroll_`x' = mean(toten_`x')
	}	
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g teachsalary_`x'=teachsal
	replace teachsalary_`x' = . if year!=`x'
	bysort scode: egen teachsal_`x' = mean(teachsalary_`x')
	}
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g ptaf_`x'=ptafees
	replace ptaf_`x' = . if year!=`x'
	bysort scode: egen ptafees_`x' = mean(ptaf_`x')
	}
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g tuit_`x'=tuitioncollected
	replace tuit_`x' = . if year!=`x'
	bysort scode: egen tuitfees_`x' = mean(tuit_`x')
	}	
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g teachsalarynbteach_`x'=teachsal/nbteach
	replace teachsalarynbteach_`x' = . if year!=`x'
	bysort scode: egen teachsalnbteach_`x' = mean(teachsalarynbteach_`x')
	}
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g teachsalarynbqualteach_`x'=teachsal/nbqualteach
	replace teachsalarynbqualteach_`x' = . if year!=`x'
	bysort scode: egen teachsalnbqualteach_`x' = mean(teachsalarynbqualteach_`x')
	}

	foreach x in 1991 1992 1993 1994 1995 2001{
	g nbt_`x'=nbteach
	replace nbt_`x' = . if year!=`x'
	bysort scode: egen nbteach_`x' = mean(nbt_`x')
	}
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g nbqt_`x'=nbqualteach
	replace nbqt_`x' = . if year!=`x'
	bysort scode: egen nbqualteach_`x' = mean(nbqt_`x')
	}	
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g totnbt_`x'=totenroll_nbteach
	replace totnbt_`x' = . if year!=`x'
	bysort scode: egen totenrollnbteach_`x' = mean(totnbt_`x')
	}
	
	foreach x in 1991 1992 1993 1994 1995 2001{
	g totnbqt_`x'=totenroll_nbqualteach
	replace totnbqt_`x' = . if year!=`x'
	bysort scode: egen totenrollnbqualteach_`x' = mean(totnbqt_`x')
	}	
	
	foreach x in 1995 1997{
	g eng3_`x'=enrollg3
	replace eng3_`x' = . if year!=`x'
	bysort scode: egen enrollg3_`x' = mean(eng3_`x')
	}	

	foreach x in 1991 1995 1997 2001{
	g eng7_`x'=enrollg7
	replace eng7_`x' = . if year!=`x'
	bysort scode: egen enrollg7_`x' = mean(eng7_`x')
	}	
	
	foreach x in 1991 1995 1997 2001{
	g test_`x'=37-ple
	replace test_`x' = . if year!=`x'
	bysort scode: egen ple_`x' = mean(test_`x')
	}	

	foreach x in 1995 2001{
	g testf_`x'=37-plef
	replace testf_`x' = . if year!=`x'
	bysort scode: egen plef_`x' = mean(testf_`x')
	}	

	foreach x in 1995 2001{
	g testm_`x'=37-plem
	replace testm_`x' = . if year!=`x'
	bysort scode: egen plem_`x' = mean(testm_`x')
	}	
	
	bysort scode: egen distnews = mean(distance)
	drop distance
	rename distnews distance
	
save "RS2005.dta", replace

