clear mata
capture clear matrix
clear 
set memory 600m
set matsize 5000
set maxvar 32767
set more off

cd ""
use "", clear

*** Table 1
*Summary statistics on the share of capitation grants reaching school in 1995 and in 2001 (in percent)

	*Panel A: original results from RS2005

	*Panel B: Pure replication
	su capture if year==1995, d
	su capture if year==2001 & panel_sample==1, d

*** Table 2
*Linking distance, head teacher's knowledge, and share of capitation grants reaching school

	*Panel A: original results from RS2005

	g diffcapture_01_95 = capture_2001 - capture_1995 if year==2001
	g diffconsump_01_95 = consump_2001 - consump_1995 if year==2001
	
	*Panel B: pure replication		
	reg ht_knowledge distance 
	predict firststage
	reg diffcapture_01_95 firststage diffconsump_01_95
	bootstrap, reps(500): reg diffcapture_01_95 firststage diffconsump_01_95
	
	*Panel C: modified replication
	ivregress 2sls capture_2001 (ht_knowledge = distance) consump_2001, first 
	estat first
	ivregress 2sls capture_2001 (ht_knowledge = distance) consump_2001, first ro
	estat first

*** Table 3
*Impact of the newspaper campaign on school total enrolment

	*Panel A: original results copied from RS2005

	g difftotenroll_01_95 = totenroll_2001 - totenroll_1995 if year==2001
	g difftotenroll_95_91 = totenroll_1995 - totenroll_1991 if year==1995	
	g diffconsump_95_91 = consump_1995 - consump_1991 if year==1995	
	
	*Panel B: pure replication
		*Col 1
		reg difftotenroll_01_95 if difftotenroll_01_95>=0
	
		*Col 2, 3
		ivregress 2sls difftotenroll_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 if difftotenroll_01_95>=0, first 	
		estat first

		*Col 4 
		reg difftotenroll_01_95 distance diffconsump_01_95 if difftotenroll_01_95>=0 

		*Col 5
		reg difftotenroll_95_91 distance diffconsump_95_91

	*Panel C: modified replication

		*Col 1	
		reg difftotenroll_01_95	
		reg difftotenroll_01_95, ro
	
		*Col 2, 3 
		ivregress 2sls difftotenroll_01_95  (diffcapture_01_95 = distance) diffconsump_01_95, first 
		estat first	
		ivregress 2sls difftotenroll_01_95  (diffcapture_01_95 = distance) diffconsump_01_95, first ro	
		estat first

		*Col 4 
		reg difftotenroll_01_95 distance diffconsump_01_95 
		reg difftotenroll_01_95 distance diffconsump_01_95, ro
	
		*Col 5 
		reg difftotenroll_95_91 distance diffconsump_95_91
		reg difftotenroll_95_91 distance diffconsump_95_91, ro
	
** Table 4
*Impact of the newspaper campaign on enrolment of P7 students: 
*Difference-in-differences analysis at the district level
preserve
use "JEEA/martina.dta", clear //data of M. Bjorkman

	g dum96=0
	replace dum96=1 if year==1996
	
	g dum02=0
	replace dum02=1 if year==2002
	
	tab2 dum96 dum02, missing
	
	ta nv, missing
	ta prschools, missing
	ta totstud, missing
	
	g nv_school=nv/prschools
	g nv_school2002=nv_school*dum02
	
	
	*Panel A: original results from RS2005

	*Panel B: pure replication
		*Col 1
		reg totstud nv_school mexp_hh if year==1996, ro 
	
		*Col 2
		reg totstud nv_school mexp_hh if year==2002, ro 
	
		*Col 3
		reg totstud nv_school2002 nv_school dum02 dum96 mexp_hh, ro noconstant

	*Panel C: modified replication

		*Col 1
		reg totstud nv_school mexp_hh if year==1996, ro 
	
		*Col 2
		reg totstud nv_school mexp_hh if year==2002, ro 
	
		*Col 3		
		ta district, gen(districtdum)
		des districtdum*
		reg totstud dum96 dum02 nv_school2002 mexp_hh districtdum*, ro noconstant
	
	**Check robustness to first-difference OLS analysis
	
		foreach x in 1996 2002{
		g consumption_`x'=mexp_hh
		replace consumption_`x' = . if year!=`x'
		bysort district: egen consump_`x' = mean(consumption_`x')
		}
	
		foreach x in 1996 2002{
		g toten_`x'=totstud
		replace toten_`x' = . if year!=`x'
		bysort district: egen totenroll_`x' = mean(toten_`x')
		}
		
		g difftotenroll_02_96 = totenroll_2002 - totenroll_1996 if year==2002
		g diffconsump_02_96 = consump_2002 - consump_1996 if year==2002	

		reg difftotenroll_02_96 nv_school diffconsump_02_96, ro

		restore


ta scode if panel_sample==1 

g pansamp=1 if ((scode>=1 & scode<=39)|(scode>=50 & scode<=67)|(scode>=79 & scode<=162)|(scode>=173 & scode<=176)|/*
*/ (scode>=178 & scode<=250))
ta pansamp if year==2001, missing

g diffenrollg7_01_95 = enrollg7_2001 - enrollg7_1995 if year==2001
g diffple_01_95 = ple_2001 - ple_1995 if year==2001

count if diffenrollg7_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<.
count if diffple_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<.	

ta scode if diffenrollg7_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<. 

g refsamp=1 if ((scode>=1 & scode<=18)|scode==22|(scode>=24 & scode<=28)|(scode>=30 & scode<=32)|scode==34|/*
*/ (scode>=36 & scode<=39)|scode==50|(scode>=52 & scode<=56)|(scode>=59 & scode<=60)|scode==62|(scode>=64 & scode<=67)|/*
*/ (scode>=79 & scode<=94)|scode==96|(scode>=99 & scode<=102)|(scode>=104 & scode<=110)|(scode>=112 & scode<=125)|/*
*/ (scode>=127 & scode<=128)|(scode>=130 & scode<=142)|scode==146|scode==148|(scode>=151 & scode<=152)|scode==154|/*
*/ (scode>=156 & scode<=161)|(scode>=173 & scode<=176)|(scode>=178 & scode<=179)|(scode>=181 & scode<=183)|/*
*/ (scode>=185 & scode<=187)|scode==191|scode==193|(scode>=196 & scode<=197)|(scode>=199 & scode<=209)|/*
*/ (scode>=211 & scode<=212)|(scode>=217 & scode<=227)|(scode>=229 & scode<=236)|scode==238|scode==240|/*
*/ (scode>=243 & scode<=250))
ta refsamp if year==2001, missing
**171 observations

g diffnbteach_01_95 = nbteach_2001 - nbteach_1995 if year==2001

count if diffenrollg7_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<. & diffnbteach_01_95<.
count if diffple_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<. & diffnbteach_01_95<.
count if diffenrollg7_01_95<. & diffple_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<. & diffnbteach_01_95<.

ta scode if diffenrollg7_01_95<. & diffple_01_95<. & diffcapture_01_95<. & diffconsump_01_95<. & distance<. & diffnbteach_01_95<.

g refsampbis=1 if ((scode>=1 & scode<=18)|scode==22|(scode>=24 & scode<=28)|(scode>=30 & scode<=32)|scode==34|/*
*/ (scode>=36 & scode<=39)|scode==50|(scode>=52 & scode<=56)|(scode>=59 & scode<=60)|scode==62|(scode>=64 & scode<=67)|/*
*/ (scode>=79 & scode<=94)|scode==96|(scode>=99 & scode<=102)|(scode>=104 & scode<=110)|(scode>=112 & scode<=122)|/*
*/ (scode>=124 & scode<=125)|/*
*/ (scode>=127 & scode<=128)|(scode>=130 & scode<=142)|scode==146|scode==148|(scode>=151 & scode<=152)|scode==154|/*
*/ (scode>=156 & scode<=161)|(scode>=173 & scode<=176)|(scode>=178 & scode<=179)|(scode>=181 & scode<=183)|/*
*/ (scode>=185 & scode<=187)|scode==191|scode==193|(scode>=196 & scode<=197)|(scode>=199 & scode<=209)|/*
*/ (scode>=211 & scode<=212)|(scode>=217 & scode<=227)|(scode>=229 & scode<=236)|scode==238|scode==240|/*
*/ (scode>=243 & scode<=250))
ta refsampbis if year==2001, missing
**170 observations


**Table 5
*Distance to a newspaper outlet and change in the share of capitation grants

g diffcapture_95_91 = capture_1995 - capture_1991 if year==1995	

	*Col 1
	reg diffcapture_95_91 distance diffconsump_95_91, ro
	*est store col1
	
	*Col 2
	reg diffcapture_01_95 distance diffconsump_01_95, ro
	*est store col2 
	

**Control for variables correlated with ability of local community to exert pressure on local officials 

	*1. consump_1995
	pwcorr distance consump_1995, sig

	*2. distbank
	ta q30dist, m
	g distbank= ln(1+q30dist)
	ta distbank if year==2001, m
	pwcorr distance distbank, sig

	*3. presence of DEO or local officials in SMC
	ta q52alo, m
	g LC_SMC=1 if q52alo==1
	replace LC_SMC=0 if q52alo==2
	ta LC_SMC, m

	ta q52bdeo, m
	g DEO_SMC=1 if q52bdeo==1
	replace DEO_SMC=0 if q52bdeo==2
	ta DEO_SMC, m

	g LCDEO_SMC=1 if (LC_SMC==1|DEO_SMC==1)
	replace LCDEO_SMC=0 if LCDEO_SMC==.
	replace LCDEO_SMC=. if (LC_SMC==. & DEO_SMC==.)
	ta LCDEO_SMC, m

	pwcorr distance LCDEO_SMC, sig

	*4. whether school received "discretionary support"
	ta q84agra, m
	ta teachsalary_2001, m
	ta q84cfee, m
	ta ptaf_2001, m
	ta q84eoth, m
	ta q84eoth if year==2001, m

	g discsupp=1 if q84eoth!=.
	replace discsupp=0 if discsupp==.
	replace discsupp=. if (q84agra==. & teachsalary_2001==. & q84cfee==. & ptaf_2001==. & q84eoth==.)
	ta discsupp, missing
	ta discsupp if year==2001, m

	pwcorr distance discsupp, sig

**Control for variables correlated with incentive of local community to exert pressure on local officials 

	*1. capture_1995 
	pwcorr distance capture_1995, sig

	*2. enrollg7_1995
	pwcorr distance enrollg7_1995, sig

	*3. ple_1995
	pwcorr distance ple_1995, sig

**Table 6
*Correlation between distance to a newspaper outlet and local community's ability and incentives to exert pressure on local officials

	pwcorr distance consump_1995 distbank LCDEO_SMC discsupp capture_1995 enrollg7_1995 ple_1995, sig	

**Table 7
*Distance to a newspaper outlet and change in the share of capitation grants 
*when controlling for UPE reform channel

	*Col 1
	reg diffcapture_01_95 distance diffconsump_01_95 consump_1995, ro

	*Col 2
	reg diffcapture_01_95 distance diffconsump_01_95 distbank, ro
	
	*Col 3
	reg diffcapture_01_95 distance diffconsump_01_95 LCDEO_SMC, ro	
		
	*Col 4	
	reg diffcapture_01_95 distance diffconsump_01_95 discsupp, ro
	
	*Col 5
	reg diffcapture_01_95 distance diffconsump_01_95 capture_1995, ro
	
	*Col 6
	reg diffcapture_01_95 distance diffconsump_01_95 enrollg7_1995, ro	
	
	*Col 7
	reg diffcapture_01_95 distance diffconsump_01_95 ple_1995, ro	
		
**Descriptive statistics displayed in section 4.2.

	**About question Q76b
	ta q76bsal, missing
	g teachsal_disclos=1 if q76bsal==1
	replace teachsal_disclos=0 if q76bsal==2
	ta teachsal_disclos

	**About question Q76c
	ta q76cupe, missing
	g capgrant_disclos=1 if q76cupe==1
	replace capgrant_disclos=0 if q76cupe==2
	ta capgrant_disclos

	
**Table 15
*Distance to a newspaper outlet and complementary school characteristics

	g diffnbteach_95_91 = nbteach_1995 - nbteach_1991 if year==1995	
		
	g teachsalbis_2001=ln(1+teachsal_2001)
	g teachsalbis_1995=ln(1+teachsal_1995)
	g teachsalbis_1991=ln(1+teachsal_1991)
		
	g ptafeesbis_2001=ln(1+ptafees_2001)
	g ptafeesbis_1995=ln(1+ptafees_1995)
	g ptafeesbis_1991=ln(1+ptafees_1991)
	
	g diffptafees_01_95 = ptafees_2001 - ptafees_1995 if year==2001
	g diffptafeesbis_01_95 = ptafeesbis_2001 - ptafeesbis_1995 if year==2001	
	g diffptafeesbis_95_91 = ptafeesbis_1995 - ptafeesbis_1991 if year==1995
	
	g diffteachsal_01_95 = teachsal_2001 - teachsal_1995 if year==2001
	g diffteachsalbis_01_95 = teachsalbis_2001 - teachsalbis_1995 if year==2001
	g diffteachsalbis_95_91 = teachsalbis_1995 - teachsalbis_1991 if year==1995
	
	g diffnewspapchannel_01_95=(diffcapture_01_95/diffteachsalbis_01_95)
	su diffteachsalbis_01_95 if year==2001
	su diffnewspapchannel_01_95 if year==2001 & refsamp==1

	g diffnewspapchannel_95_91=(diffcapture_95_91/diffteachsalbis_95_91)
	su diffteachsalbis_95_91 if year==1995
	su diffnewspapchannel_95_91 if year==1995 & refsamp==1
	
	rename diffptafeesbis_01_95 diffupechannel_01_95
	rename diffptafeesbis_95_91 diffupechannel_95_91
	
	su diffupechannel_01_95
	su diffupechannel_95_91

	g diffenrollg7_95_91 = enrollg7_1995 - enrollg7_1991 if year==1995
	g diffple_95_91 = ple_1995 - ple_1991 if year==1995
	
	*Col 1
	reg diffupechannel_95_91 distance diffconsump_95_91, ro
	reg diffupechannel_95_91 distance diffupechannel_95_91 diffteachsalbis_95_91 diffenrollg7_95_91 diffconsump_95_91, ro	
	
	*Col 2
	reg diffupechannel_01_95 distance diffconsump_01_95, ro
	reg diffupechannel_01_95 distance diffupechannel_01_95 diffteachsalbis_01_95 diffenrollg7_01_95 diffconsump_01_95, ro	
	
	*Col 3
	reg diffteachsalbis_95_91 distance diffconsump_95_91, ro	
	reg diffteachsalbis_95_91 distance diffupechannel_95_91 diffteachsalbis_95_91 diffenrollg7_95_91 diffconsump_95_91, ro
	
	*Col 4
	reg diffteachsalbis_01_95 distance diffconsump_01_95, ro
	reg diffteachsalbis_01_95 distance diffupechannel_01_95 diffteachsalbis_01_95 diffenrollg7_01_95 diffconsump_01_95, ro	
	
	*Col 5 (current)
	reg diffnbteach_95_91 distance diffconsump_95_91, ro
	reg diffnbteach_95_91 distance diffupechannel_95_91 diffteachsalbis_95_91 diffenrollg7_95_91 diffconsump_95_91, ro
	
	*Col 6 
	reg diffnbteach_01_95 distance diffconsump_01_95, ro	
	reg diffnbteach_01_95 distance diffupechannel_01_95 diffteachsalbis_01_95 diffenrollg7_01_95 diffconsump_01_95, ro

**Table 8
*Impact of the newspaper campaign on enrolment of P7 students

	**Col 1
	reg diffcapture_01_95 distance diffconsump_01_95 if refsamp==1, ro
	
	**Col 2
	ivreg2 diffenrollg7_01_95  (diffcapture_01_95 = distance) diffconsump_01_95, first ro
	
	**Col 3
	reg diffcapture_01_95 distance diffconsump_01_95 diffple_01_95 if refsamp==1, ro
	
	**Col 4 
	ivreg2 diffenrollg7_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffple_01_95, first ro
	
	**Col 5
	reg diffcapture_01_95 distance diffconsump_01_95 diffnbteach_01_95 if refsamp==1, ro

	**Col 6	
	ivreg2 diffenrollg7_01_95  (diffcapture_01_95 = distance) diffnbteach_01_95, first ro
	
	**Col 7
	reg diffcapture_01_95 distance diffconsump_01_95 diffnbteach_01_95 diffple_01_95 if refsamp==1, ro

	**Col 8	
	ivreg2 diffenrollg7_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffnbteach_01_95 diffple_01_95, first ro
	
**Replication of results of col 1 and col 4 of Table 7 in RS (2011)
	
	set more off
	hadimvo enrollg7 capture distance if (year==1995|year==2001), gen(h1) 
	tab h1, missing	
	ivregress 2sls diffenrollg7_01_95 (diffcapture_01_95 = distance) diffconsump_01_95 if h1==0, first ro	
	
**Table 9
*Impact of the newspaper campaign on enrolment of P7 students: analysis at the district level
	bysort scode: egen districtcode = mean(districtn)
	
	g distancepansamp=distance if pansamp==1
	bysort districtcode: egen districtdistance_pansamp = mean(distancepansamp) if year==2001
	ta districtdistance_pansamp, m

	foreach x in 1991 1995 2001{
	g eng7district_`x'=enrollg7 if pansamp==1
	replace eng7district_`x' = . if year!=`x'
	bysort districtcode: egen enrollg7district_`x' = mean(eng7district_`x')
	}	
	
	foreach x in 1991 1995 2001{
	g capdistrict_`x'=capture if pansamp==1
	replace capdistrict_`x' = . if year!=`x'
	bysort districtcode: egen capturedistrict_`x' = mean(capdistrict_`x')
	}	

	foreach x in 1991 1995 2001{
	g condistrict_`x'=consump if pansamp==1
	replace condistrict_`x' = . if year!=`x'
	bysort districtcode: egen consumpdistrict_`x' = mean(condistrict_`x')
	}	

	foreach x in 1991 1995 2001{
	g testdistrict_`x'=37-ple if pansamp==1
	replace testdistrict_`x' = . if year!=`x'
	bysort districtcode: egen pledistrict_`x' = mean(testdistrict_`x')
	}

	foreach x in 1991 1995 2001{
	g nbteacherdistrict_`x'=nbteach if pansamp==1
	replace nbteacherdistrict_`x' = . if year!=`x'
	bysort districtcode: egen nbteachdistrict_`x' = mean(nbteacherdistrict_`x')
	}	
	
	foreach x in 1991 1995 2001{
	g teachsalarydistrict_`x'=teachsal if pansamp==1
	replace teachsalarydistrict_`x' = . if year!=`x'
	bysort districtcode: egen teachsaldistrict_`x' = mean(teachsalarydistrict_`x')
	}	
	
	g diffdistrictenrollg7_01_95=enrollg7district_2001-enrollg7district_1995 if year==2001
	ta diffdistrictenrollg7_01_95, m

	g diffdistrictcapture_01_95=capturedistrict_2001-capturedistrict_1995 if year==2001
	ta diffdistrictcapture_01_95, m

	g diffdistrictconsump_01_95=consumpdistrict_2001-consumpdistrict_1995 if year==2001
	ta diffdistrictconsump_01_95, m

	g diffdistrictple_01_95=pledistrict_2001-pledistrict_1995 if year==2001
	ta diffdistrictple_01_95, m

	g diffdistrictnbteach_01_95=nbteachdistrict_2001-nbteachdistrict_1995 if year==2001
	ta diffdistrictnbteach_01_95, m

	g diffdistrictteachsal_01_95=teachsaldistrict_2001-teachsaldistrict_1995 if year==2001
	ta diffdistrictteachsal_01_95, m

	sort districtcode
	g uniqueidschool_district=1 
	quietly by districtcode: replace uniqueidschool_district=uniqueidschool_district[_n-1]+1 if uniqueidschool_district[_n-1]!=.
	count if uniqueidschool_district==1 
	ta uniqueidschool_district, m

	bysort districtcode: egen diffdistrictenrollg7_01_95bis = mean(diffdistrictenrollg7_01_95)
	bysort districtcode: egen diffdistrictcapture_01_95b = mean(diffdistrictcapture_01_95)
	bysort districtcode: egen diffdistrictconsump_01_95bis = mean(diffdistrictconsump_01_95)
	bysort districtcode: egen districtdistance_pansampbis = mean(districtdistance_pansamp)
	bysort districtcode: egen diffdistrictple_01_95bis = mean(diffdistrictple_01_95)
	bysort districtcode: egen diffdistrictnbteach_01_95bis = mean(diffdistrictnbteach_01_95)
	bysort districtcode: egen diffdistrictteachsal_01_95bis = mean(diffdistrictteachsal_01_95)

	**Col 1
	reg diffdistrictcapture_01_95b districtdistance_pansampbis diffdistrictnbteach_01_95bis diffdistrictple_01_95bis diffdistrictconsump_01_95bis if uniqueidschool_district==1, first ro
	
	**Col 2
	ivreg2 diffdistrictenrollg7_01_95bis  (diffdistrictcapture_01_95b = districtdistance_pansampbis) diffdistrictple_01_95bis diffdistrictnbteach_01_95bis diffdistrictconsump_01_95bis if uniqueidschool_district==1, first ro
	est store col2

**Table 10
*Distance to a newspaper outlet and change in enrolment of P7 students

	**Col 1
	reg diffenrollg7_95_91 distance diffconsump_95_91, ro
	
	**Col 2
	reg diffenrollg7_01_95 distance diffconsump_01_95, ro

	**Col 3
	reg diffenrollg7_95_91 distance diffconsump_95_91 diffple_95_91, ro
	
	**Col 4
	reg diffenrollg7_01_95 distance diffconsump_01_95 diffple_01_95, ro
	
	**Col 5
	reg diffenrollg7_95_91 distance diffconsump_95_91 diffnbteach_95_91, ro
	
	**Col 6
	reg diffenrollg7_01_95 distance diffconsump_01_95 diffnbteach_01_95, ro
	
	**Col 7
	reg diffenrollg7_95_91 distance diffconsump_95_91 diffnbteach_95_91 diffple_95_91, ro
	
	**Col 8
	reg diffenrollg7_01_95 distance diffconsump_01_95 diffnbteach_01_95 diffple_01_95, ro
	
*****************************
*****************************
**IMPACT OF DISTANCE ON PLE**
*****************************
*****************************

**Table 11
*Impact of the newspaper campaign on PLE scores of P7 students

	**Col 1
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) diffconsump_01_95, first ro
	
	reg diffcapture_01_95 distance diffconsump_01_95 if refsamp==1, ro
	predict diffcapturehat_01_95, xb

	pwcorr diffple_01_95 ple_1995, sig
	pwcorr diffcapturehat_01_95 ple_1995, sig

	**Col 2
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffenrollg7_01_95, first ro
	
	**Col 3	
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffnbteach_01_95, first ro
	
	**Col 4
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 ple_1995, first ro
	
	**Col 5	
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffenrollg7_01_95 diffnbteach_01_95 ple_1995, first ro
	
	**Replication of the results of col 1 of Table 8 of RS (2011)
	hadimvo ple distance if (year==1995 | year==1997 | year==2001) , gen(h2)
	tab h2, missing
	tab region, gen(regionid)		
	ivreg2 diffple_01_95 (diffcapture_01_95 = distance) diffconsump_01_95 regionid* if h2==0, ro
	
**Table 12
*Impact of the newspaper campaign on PLE scores of P7 students:
*Analysis at the district level

bysort districtcode: egen districtple_1995 = mean(ple_1995)

	**Col 1
	reg diffdistrictcapture_01_95b districtdistance_pansampbis districtple_1995 diffdistrictenrollg7_01_95bis diffdistrictnbteach_01_95bis diffdistrictconsump_01_95bis if uniqueidschool_district==1, ro
	
	**Col 2
	ivreg2 diffdistrictple_01_95bis  (diffdistrictcapture_01_95b = districtdistance_pansampbis) districtple_1995 diffdistrictenrollg7_01_95bis diffdistrictnbteach_01_95bis diffdistrictconsump_01_95bis if uniqueidschool_district==1, first ro
	
	
**Table 13
*Distance to a newspaper outlet and change in PLE scores of P7 students

	**Col 1
	reg diffple_95_91 distance diffconsump_95_91, ro
	
	**Col 2
	reg diffple_01_95 distance diffconsump_01_95, ro
	
	**Col 3
	reg diffple_95_91 distance diffconsump_95_91 diffenrollg7_95_91, ro	
	
	**Col 4
	reg diffple_01_95 distance diffconsump_01_95 diffenrollg7_01_95, ro	
	
	**Col 5
	reg diffple_95_91 distance diffconsump_95_91 diffnbteach_95_91, ro	
	
	**Col 6
	reg diffple_01_95 distance diffconsump_01_95 diffnbteach_01_95, ro	
	
	**Col 7
	reg diffple_95_91 distance diffconsump_95_91 ple_1991, ro	
	
	**Col 8
	reg diffple_01_95 distance diffconsump_01_95 ple_1995, ro	
	
	**Col 9
	reg diffple_95_91 distance diffconsump_95_91 diffnbteach_95_91 diffenrollg7_95_91 ple_1991, ro	
	
	**Col 10
	reg diffple_01_95 distance diffconsump_01_95 diffnbteach_01_95 diffenrollg7_01_95 ple_1995, ro	

**Table 14
*Impact of the newspaper campaign on PLE scores of P7 students:
*Controlling for competing channels

	*Col 1
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) consump_1995 diffconsump_01_95 diffenrollg7_01_95 diffnbteach_01_95 ple_1995, first ro
	
	*Col 2
	ivreg2 diffple_01_95  (diffcapture_01_95 = distance) distbank diffconsump_01_95 diffenrollg7_01_95 diffnbteach_01_95 ple_1995, first ro
	
**************	
**DISCUSSION**
**************	

**Table 8
	**Col 7
	reg diffcapture_01_95 distance diffconsump_01_95 diffnbteach_01_95 diffple_01_95 if refsampbis==1, ro
	predict diffcapture_01_95hat, xb	
	
	**Col 8 
	ivreg2 diffenrollg7_01_95  (diffcapture_01_95 = distance) diffconsump_01_95 diffnbteach_01_95 diffple_01_95, first ro
	sum distance diffcapture_01_95 diffenrollg7_01_95 if (refsampbis==1 & year==2001)

**Table 15
	**Col 6
	reg diffnbteach_01_95 distance diffconsump_01_95, ro
	sum distance diffnbteach_01_95 if diffnbteach_01_95<. & distance<. & diffconsump_01_95<. & year==2001
